==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/id.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Tautan publik",
    "Photos" : "Foto",
    "Your memories under your control" : "Kenangan Anda di bawah kendali Anda",
    "All media" : "Semua media",
    "Videos" : "Video",
    "Albums" : "Album",
    "Collaborative albums" : "Album kolaboratif",
    "People" : "Orang",
    "Folders" : "Folder",
    "Favorites" : "Disukai",
    "On this day" : "Pada hari ini",
    "Shared with you" : "Shared with you",
    "Tags" : "Tag",
    "Places" : "Tempat",
    "Map" : "Peta",
    "Photos settings" : "Setelan foto",
    "Mark selection as favorite" : "Tandai pilihan sebagai favorit",
    "Add selection to favorites" : "Tambahkan pilihan ke favorit",
    "Remove selection from favorites" : "Hapus pilihan dari favorit",
    "Name of the album" : "Nama album",
    "Location of the album" : "Lokasi album",
    "Back" : "Kembali",
    "Add collaborators" : "Tambahkan kolaborator",
    "Save" : "Simpan",
    "Create album" : "Buat album",
    "Add to Album" : "Tambahkan ke Album",
    "Add selection to album {albumName}" : "Tambahkan pilihan ke album {albumName}",
    "Shared by" : "Dibagikan oleh",
    "Create a new album." : "Buat sebuah album baru.",
    "Create new album" : "Buat album baru",
    "New album" : "Album baru",
    "_%n item_::_%n photos and videos_" : ["%n foto dan video"],
    "Failed to fetch collaborators list." : "Gagal mendapatkan daftar kolaborator.",
    "Failed to update album." : "Gagal memperbarui album.",
    "Add people or groups who can edit your album" : "Tambahkan orang atau grup yang dapat menyunting album Anda",
    "Search people or groups" : "Cari orang atau grup",
    "No recommendations. Start typing." : "Tidak ada saran. Mulai mengetik.",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "Hapus {collaboratorLabel} dari daftar kolaborator",
    "Copy the public link" : "Salin tautan publik",
    "Public link copied!" : "Tautan publik disalin!",
    "Copy public link" : "Salin tautan publik",
    "Delete the public link" : "Hapus tautan publik",
    "Create public link share" : "Buat berbagi tautan publik",
    "Share via public link" : "Bagikan melalui tautan publik",
    "This collection does not exist" : "Koleksi ini tidak ada",
    "An error occurred" : "Terjadi kesalahan",
    "_%n photos_::_%n photos_" : ["%n foto"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto yang belum ditetapkan"],
    "Favorite" : "Favorit",
    "Open the full size \"{name}\" image" : "Buka gambar \"{name}\" ukuran penuh",
    "Select image {imageName}" : "Pilih gambar {imageName}",
    "Go back" : "Kembali",
    "Add to {destination}" : "Tambahkan ke {destination}",
    "There are no photos or videos yet!" : "Belum ada foto atau video!",
    "_{years} year ago_::_{years} years ago_" : ["{years} tahun yang lalu"],
    "Enable squared photos view" : "Aktifkan tampilan foto kotak",
    "Home" : "Beranda",
    "Choose default Photos upload and Albums location" : "PIlih lokasi unggahan Foto dan lokasi Album bawaan",
    "View" : "Tampilan",
    "_%n photo_::_%n photos_" : ["%n foto"],
    "Unselect all" : "Batalkan semua pemilihan",
    "Add photos to this album" : "Tambahkan foto ke album ini",
    "Manage collaborators for this album" : "Kelola kolaborator untuk album ini",
    "Open actions menu" : "Buka menu tindakan",
    "Edit album details" : "Sunting detail album",
    "Download all files in album" : "Unduh semua berkas dalam album",
    "Delete album" : "Hapus album",
    "Download selected files" : "Unduh berkas yang dipilih",
    "Remove selection from album" : "Hapus pilihan dari album",
    "This album does not have any photos or videos yet!" : "Album ini belum memiliki foto atau video apa pun!",
    "Add photos to {albumName}" : "Tambahkan foto ke {albumName}",
    "Manage collaborators" : "Kelola kolaborator",
    "Save collaborators for this album." : "Simpan kolaborator untuk album ini",
    "Cover photo for album {albumName}" : "Foto cover untuk album {albumName}",
    "There is no album yet!" : "Belum ada album!",
    "This person could not be found" : "Orang ini tidak dapat ditemukan",
    "Rename person" : "Ubah nama orang",
    "Merge with different person" : "Gabungkan dengan orang yang berbeda",
    "Download selected photos" : "Unduh foto yang dipilih",
    "Remove from favorites" : "Remove from favorites",
    "Remove person" : "Hapus orang",
    "Name of this person" : "Nama orang ini",
    "Save." : "Simpan.",
    "Merge person" : "Gabungkan orang",
    "Move to different person" : "Pindahkan ke orang lain",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Pindahkan foto ke orang yang berbeda"],
    "_Remove photo from person_::_Remove photos from person_" : ["Hapus foto dari orang"],
    "This might take some time depending on the size of your photo library." : "Ini mungkin membutuhkan beberapa waktu tergantung pada ukuran pustaka foto Anda.",
    "Recognized people will show up here" : "Orang yang dikenal akan muncul di sini",
    "This folder does not exist" : "Folder ini tidak ada",
    "Loading folders …" : "Memuat folder…",
    "No photos in here" : "Tidak ada foto di sini",
    "Taken on {date} at {time}" : "Diambil pada tanggal {date}, jam {time}",
    "This place does not have any photos or videos yet!" : "Tempat ini belum memiliki foto atau video apa pun!",
    "Add photos to this place" : "Tambahkan foto ke tempat ini",
    "Cover photo for place {placeName}" : "Foto cover untuk tempat {placeName}",
    "There is no place yet!" : "Belum ada tempat!",
    "Back to tags overview" : "Kembali ke ikhtisar tag",
    "No photos with this tag yet" : "Belum ada foto dengan tag ini",
    "No tags yet" : "Belum ada tag",
    "Photos with tags will show up here" : "Foto dengan tag akan muncul di sini",
    "Popular tags" : "Tag populer",
    "Add to album" : "Tambahkan album",
    "Delete selection" : "Hapus pilihan",
    "No photos or videos in here" : "Tidak ada foto atau video di sini",
    "Unassigned faces" : "Wajah yang belum ditetapkan",
    "Failed to fetch collection." : "Gagal mengambil koleksi.",
    "Failed to fetch collections list." : "Gagal mendapatkan daftar koleksi.",
    "Failed to fetch faces list." : "Gagal mendapatkan daftar wajah.",
    "All your media" : "Semua media Anda",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Album Terbagi",
    "Shared album {title}" : "Album terbagi {title}",
    "Public album {title}" : "Album publik {title}",
    "Tagged photos" : "Foto yang memiliki tag",
    "Tagged photo {title}" : "Foto memiliki tag {title} ",
    "{title}'s face" : "Wajah {title}",
    "{startDate} to {endDate}" : "{startDate} ke {endDate}",
    "Details" : "Detail",
    "Back to {folder}" : "Kembali ke {folder}",
    "Share this folder" : "Bagikan folder ini",
    "Add" : "Masukkan"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/id.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Tautan publik",
    "Photos" : "Foto",
    "On This Day" : "Pada Hari Ini",
    "Your memories under your control" : "Kenangan Anda di bawah kendali Anda",
    "All media" : "Semua media",
    "Videos" : "Video",
    "Albums" : "Album",
    "Collaborative albums" : "Album kolaboratif",
    "People" : "Orang",
    "Folders" : "Folder",
    "Favorites" : "Disukai",
    "On this day" : "Pada hari ini",
    "Shared with you" : "Shared with you",
    "Tags" : "Tag",
    "Places" : "Tempat",
    "Map" : "Peta",
    "Photos settings" : "Setelan foto",
    "Mark selection as favorite" : "Tandai pilihan sebagai favorit",
    "Add selection to favorites" : "Tambahkan pilihan ke favorit",
    "Remove selection from favorites" : "Hapus pilihan dari favorit",
    "This name is already in use." : "Nama ini sudah digunakan.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" tidak diperbolehkan di dalam nama file.",
    "Invalid filename." : "Nama file tidak valid.",
    "Name of the album" : "Nama album",
    "Location of the album" : "Lokasi album",
    "Back" : "Kembali",
    "Add collaborators" : "Tambahkan kolaborator",
    "Save" : "Simpan",
    "Create album" : "Buat album",
    "Add to Album" : "Tambahkan ke Album",
    "Add selection to album {albumName}" : "Tambahkan pilihan ke album {albumName}",
    "Shared by" : "Dibagikan oleh",
    "Create a new album." : "Buat sebuah album baru.",
    "Create new album" : "Buat album baru",
    "New album" : "Album baru",
    "_%n item_::_%n photos and videos_" : ["%n foto dan video"],
    "Failed to fetch collaborators list." : "Gagal mendapatkan daftar kolaborator.",
    "Failed to update album." : "Gagal memperbarui album.",
    "Add people or groups who can edit your album" : "Tambahkan orang atau grup yang dapat menyunting album Anda",
    "Search people or groups" : "Cari orang atau grup",
    "No recommendations. Start typing." : "Tidak ada saran. Mulai mengetik.",
    "Copy the public link" : "Salin tautan publik",
    "Public link copied!" : "Tautan publik disalin!",
    "Copy public link" : "Salin tautan publik",
    "Delete the public link" : "Hapus tautan publik",
    "Create public link share" : "Buat berbagi tautan publik",
    "Share via public link" : "Bagikan melalui tautan publik",
    "This collection does not exist" : "Koleksi ini tidak ada",
    "An error occurred" : "Terjadi kesalahan",
    "No picture for this day" : "Tidak ada gambar untuk hari ini",
    "Picture taken on this day will show up here." : "Foto yang diambil pada hari ini akan muncul di sini.",
    "More photos from this day" : "Foto lainnya dari hari ini",
    "_%n photos_::_%n photos_" : ["%n foto"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto yang belum ditetapkan"],
    "Favorite" : "Favorit",
    "Favorite image, open the full size \"{name}\" image" : "Jadikan gambar favorit, buka gambar \"{name}\" ukuran penuh",
    "Open the full size \"{name}\" image" : "Buka gambar \"{name}\" ukuran penuh",
    "Select image {imageName}" : "Pilih gambar {imageName}",
    "Open the \"{name}\" folder" : "Buka folder \"{name}\"",
    "Go back" : "Kembali",
    "Select a custom date range" : "Pilih rentang tanggal kustom",
    "Select a date range" : "Pilih rentang tanggal",
    "Date range" : "Rentang tanggal",
    "Select filters" : "Pilih filter",
    "Dates" : "Tanggal",
    "Jump to specific date in list" : "Lompat ke tanggal tertentu dalam daftar",
    "Jump to {date}" : "Lompat ke {date}",
    "Add to {destination}" : "Tambahkan ke {destination}",
    "The destination folder is owned by {owner}" : "Folder tujuan dimiliki oleh {owner}",
    "There are no photos or videos yet!" : "Belum ada foto atau video!",
    "_{years} year ago_::_{years} years ago_" : ["{years} tahun yang lalu"],
    "Squared photos view" : "Tampilan foto kotak-kotak",
    "Delete source directory" : "Hapus direktori sumber",
    "Pick folder" : "Pilih folder",
    "Select a source folder for your media" : "Pilih folder sumber untuk media Anda",
    "Media folders" : "Folder media",
    "Choose the folders from where photos and videos are shown." : "Pilih folder tempat foto dan video ditampilkan.",
    "All folders" : "Semua folder",
    "Add a Photos source for the timelines" : "Tambahkan sumber Foto untuk lini masa",
    "Add folder" : "Tambah folder",
    "Home" : "Beranda",
    "Select the default upload location for your media" : "Pilih lokasi unggah default untuk media Anda",
    "Upload folder" : "Folder unggahan",
    "General" : "Umum",
    "_%n photo_::_%n photos_" : ["%n foto"],
    "Unselect all" : "Batalkan semua pemilihan",
    "Add photos to this album" : "Tambahkan foto ke album ini",
    "Manage collaborators for this album" : "Kelola kolaborator untuk album ini",
    "Open actions menu" : "Buka menu tindakan",
    "Edit album details" : "Sunting detail album",
    "Download all files in album" : "Unduh semua berkas dalam album",
    "Delete album" : "Hapus album",
    "Download selected files" : "Unduh berkas yang dipilih",
    "Remove selection from album" : "Hapus pilihan dari album",
    "This album does not have any photos or videos yet!" : "Album ini belum memiliki foto atau video apa pun!",
    "Add photos to {albumName}" : "Tambahkan foto ke {albumName}",
    "Manage collaborators" : "Kelola kolaborator",
    "Save collaborators for this album." : "Simpan kolaborator untuk album ini.",
    "Cover photo for album {albumName}" : "Foto cover untuk album {albumName}",
    "There is no album yet!" : "Belum ada album!",
    "This person could not be found" : "Orang ini tidak dapat ditemukan",
    "Rename person" : "Ubah nama orang",
    "Merge with different person" : "Gabungkan dengan orang yang berbeda",
    "Download selected photos" : "Unduh foto yang dipilih",
    "Remove from favorites" : "Remove from favorites",
    "Remove person" : "Hapus orang",
    "Name of this person" : "Nama orang ini",
    "Save." : "Simpan.",
    "Merge person" : "Gabungkan orang",
    "Move to different person" : "Pindahkan ke orang lain",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Pindahkan foto ke orang yang berbeda"],
    "_Remove photo from person_::_Remove photos from person_" : ["Hapus foto dari orang"],
    "This might take some time depending on the size of your photo library." : "Ini mungkin membutuhkan beberapa waktu tergantung pada ukuran pustaka foto Anda.",
    "Recognized people will show up here" : "Orang yang dikenal akan muncul di sini",
    "This folder does not exist" : "Folder ini tidak ada",
    "Loading folders…" : "Memuat folder…",
    "No photos in here" : "Tidak ada foto di sini",
    "Taken on {date} at {time}" : "Diambil pada tanggal {date}, jam {time}",
    "This place does not have any photos or videos yet!" : "Tempat ini belum memiliki foto atau video apa pun!",
    "Add photos to this place" : "Tambahkan foto ke tempat ini",
    "Cover photo for place {placeName}" : "Foto cover untuk tempat {placeName}",
    "There is no place yet!" : "Belum ada tempat!",
    "Cover photo for shared album {albumName}" : "Foto sampul untuk album bersama {albumName}",
    "Back to tags overview" : "Kembali ke ikhtisar tag",
    "No photos with this tag yet" : "Belum ada foto dengan tag ini",
    "No tags yet" : "Belum ada tag",
    "Photos with tags will show up here" : "Foto dengan tag akan muncul di sini",
    "Popular tags" : "Tag populer",
    "All tags" : "Semua tag",
    "Create new album from filters" : "Buat album baru dari filter",
    "One of the source folders does not exist" : "Salah satu folder sumber tidak ada",
    "Add to album" : "Tambahkan album",
    "Delete selection" : "Hapus pilihan",
    "No photos or videos in here" : "Tidak ada foto atau video di sini",
    "Unassigned faces" : "Wajah yang belum ditetapkan",
    "Failed to fetch collection." : "Gagal mengambil koleksi.",
    "Failed to fetch collections list." : "Gagal mendapatkan daftar koleksi.",
    "Failed to fetch faces list." : "Gagal mendapatkan daftar wajah.",
    "Error fetching files" : "Kesalahan saat mengambil file",
    "All your media" : "Semua media Anda",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Album Terbagi",
    "Shared album {title}" : "Album terbagi {title}",
    "Public album {title}" : "Album publik {title}",
    "Tagged photos" : "Foto yang memiliki tag",
    "Tagged photo {title}" : "Foto memiliki tag {title}",
    "{title}'s face" : "Wajah {title}",
    "Last week" : "Minggu lalu",
    "Last Month" : "Bulan Lalu",
    "Custom…" : "Kustom…",
    "{startDate} to {endDate}" : "{startDate} ke {endDate}",
    "Details" : "Detail",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Gagal menambahkan {fileBaseName} ke koleksi {collectionFileName}",
    "Failed to delete {fileBaseName}" : "Gagal menghapus {fileBaseName}",
    "Failed to create {collectionFileName}" : "Gagal membuat {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Gagal mengganti nama {currentCollectionFileName} menjadi {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Gagal memperbarui properti {collectionFileName} dengan {properties}",
    "Delete collection" : "Hapus koleksi",
    "Leave shared album" : "Tinggalkan album bersama",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Apakah Anda yakin ingin menghapus {collectionName}? Tindakan ini tidak dapat dibatalkan.",
    "Failed to delete {collectionFileName}" : "Gagal menghapus {collectionFileName}",
    "Cancel" : "Cancel",
    "Confirm" : "Konfirmasi",
    "Failed to move {fileBaseName} to person {faceName}" : "Gagal memindahkan {fileBaseName} ke orang {faceName}",
    "Failed to remove {fileBaseName}" : "Gagal menghapus {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Gagal mengganti nama {oldName} menjadi {faceName}",
    "Failed to delete {faceName}" : "Gagal menghapus {faceName}",
    "Failed to delete {fileId}" : "Gagal menghapus {fileId}",
    "Failed to delete {fileName}" : "Gagal menghapus {fileName}",
    "Failed to set favorite state for {fileId}" : "Gagal menetapkan status favorit untuk {fileId}",
    "Failed to set favorite state for {fileName}" : "Gagal menetapkan status favorit untuk {fileName}",
    "Could not load photos folder" : "Tidak dapat memuat folder foto",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "Hapus {collaboratorLabel} dari daftar kolaborator",
    "Back to {folder}" : "Kembali ke {folder}",
    "Share this folder" : "Bagikan folder ini",
    "Enable squared photos view" : "Aktifkan tampilan foto kotak",
    "Choose default Photos upload and Albums location" : "PIlih lokasi unggahan Foto dan lokasi Album bawaan",
    "Choose a different folder" : "Pilih folder lain",
    "View" : "Tampilan",
    "Choose the folder where photos and albums are uploaded to." : "Pilih folder tempat foto dan album diunggah.",
    "Loading folders …" : "Memuat folder…",
    "Add" : "Masukkan"
},
"nplurals=1; plural=0;");
